==> hub_rest_client-0.1.1-py3-none-any.whl: hub_rest_client/api/default/get_dashboards_dashboard_id_permissions.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.items_page import ItemsPage
from ...types import UNSET, Response, Unset


def _get_kwargs(
    dashboard_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "permission",
) -> Dict[str, Any]:
    url = "{}/dashboards/{dashboardId}/permissions".format(client.hub_base_url, dashboardId=dashboard_id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "fields": fields,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[ItemsPage]:
    if response.status_code == 200:
        response_200 = ItemsPage.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[ItemsPage]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    dashboard_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "permission",
) -> Response[ItemsPage]:
    kwargs = _get_kwargs(
        dashboard_id=dashboard_id,
        client=client,
        fields=fields,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    dashboard_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "permission",
) -> Optional[ItemsPage]:
    """ """

    return sync_detailed(
        dashboard_id=dashboard_id,
        client=client,
        fields=fields,
    ).parsed


async def asyncio_detailed(
    dashboard_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "permission",
) -> Response[ItemsPage]:
    kwargs = _get_kwargs(
        dashboard_id=dashboard_id,
        client=client,
        fields=fields,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    dashboard_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "permission",
) -> Optional[ItemsPage]:
    """ """

    return (
        await asyncio_detailed(
            dashboard_id=dashboard_id,
            client=client,
            fields=fields,
        )
    ).parsed

==> hub_rest_client-0.1.2-py3-none-any.whl: hub_rest_client/api/default/get_dashboards_dashboard_id_permissions.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models import items_page as items_page_m
from ...types import UNSET, Response, Unset


def _get_kwargs(
    dashboard_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "permission",
) -> Dict[str, Any]:
    url = "{}/dashboards/{dashboardId}/permissions".format(client.hub_base_url, dashboardId=dashboard_id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "fields": fields,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[items_page_m.ItemsPage]:
    if response.status_code == 200:
        response_200 = items_page_m.ItemsPage.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[items_page_m.ItemsPage]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    dashboard_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "permission",
) -> Response[items_page_m.ItemsPage]:
    kwargs = _get_kwargs(
        dashboard_id=dashboard_id,
        client=client,
        fields=fields,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    dashboard_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "permission",
) -> Optional[items_page_m.ItemsPage]:
    """ """

    return sync_detailed(
        dashboard_id=dashboard_id,
        client=client,
        fields=fields,
    ).parsed


async def asyncio_detailed(
    dashboard_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "permission",
) -> Response[items_page_m.ItemsPage]:
    kwargs = _get_kwargs(
        dashboard_id=dashboard_id,
        client=client,
        fields=fields,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    dashboard_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "permission",
) -> Optional[items_page_m.ItemsPage]:
    """ """

    return (
        await asyncio_detailed(
            dashboard_id=dashboard_id,
            client=client,
            fields=fields,
        )
    ).parsed
